Module error

Module error 

Enums

DecodeError
Errors that can occur while decoding Modbus data from an input buffer.
EncodeError
Errors that can occur while encoding Modbus data into an output buffer.