ExceptionCode

Enum ExceptionCode 

#[non_exhaustive]
pub enum ExceptionCode { IllegalFunction, IllegalDataAddress, IllegalDataValue, ServerDeviceFailure, Acknowledge, ServerDeviceBusy, MemoryParityError, GatewayPathUnavailable, GatewayTargetFailedToRespond, Unknown(u8), }
Modbus exception codes returned by a device to indicate an error.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


IllegalFunction

0x01 — The function code is not supported.



IllegalDataAddress

0x02 — The data address is not valid.



IllegalDataValue

0x03 — The data value is not valid.



ServerDeviceFailure

0x04 — An unrecoverable error occurred on the server.



Acknowledge

0x05 — The request has been accepted but will take time to process.



ServerDeviceBusy

0x06 — The server is busy processing another request.



MemoryParityError

0x08 — Memory parity error detected.



GatewayPathUnavailable

0x0A — The gateway path is not available.



GatewayTargetFailedToRespond

0x0B — The gateway target device failed to respond.



Unknown(u8)

An exception code not defined in the standard.

Implementations

Source

impl ExceptionCode

pub const fn from_u8(value: u8) -> Self

Parse an exception code from its wire byte value.

Source

impl ExceptionCode

pub const fn as_u8(self) -> u8

Return the wire byte value for this exception code.