FunctionCode

Enum FunctionCode 

#[non_exhaustive]
pub enum FunctionCode {
Show 14 variants ReadCoils, ReadDiscreteInputs, ReadHoldingRegisters, ReadInputRegisters, WriteSingleCoil, WriteSingleRegister, WriteMultipleCoils, WriteMultipleRegisters, MaskWriteRegister, ReadWriteMultipleRegisters, ReadExceptionStatus, Diagnostics, ReadFifoQueue, Custom(u8),
}
Modbus function codes identifying the type of request or response.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ReadCoils

FC01 — Read Coils.



ReadDiscreteInputs

FC02 — Read Discrete Inputs.



ReadHoldingRegisters

FC03 — Read Holding Registers.



ReadInputRegisters

FC04 — Read Input Registers.



WriteSingleCoil

FC05 — Write Single Coil.



WriteSingleRegister

FC06 — Write Single Register.



WriteMultipleCoils

FC15 (0x0F) — Write Multiple Coils.



WriteMultipleRegisters

FC16 (0x10) — Write Multiple Registers.



MaskWriteRegister

FC22 (0x16) — Mask Write Register.



ReadWriteMultipleRegisters

FC23 (0x17) — Read/Write Multiple Registers.



ReadExceptionStatus

FC07 — Read Exception Status.



Diagnostics

FC08 — Diagnostics.



ReadFifoQueue

FC24 (0x18) — Read FIFO Queue.



Custom(u8)

A function code not recognised by this library.

Implementations

Source

impl FunctionCode

pub const fn as_u8(self) -> u8

Return the wire byte value for this function code.

pub fn from_u8(value: u8) -> Result<Self, DecodeError>

Parse a function code from its wire byte value.

pub const fn is_exception(value: u8) -> bool

Returns true if the high bit (0x80) is set, indicating an exception response.