Module error
rustmod_
core
0.2.0
Module error
Module Items
Enums
In crate rustmod_
core
rustmod_core
Module
error
Enums

Decode
Error
Errors that can occur while decoding Modbus data from an input buffer.
Encode
Error
Errors that can occur while encoding Modbus data into an output buffer.